==> haskell-wide-word-0.1.6.0-27-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wide-word
version:              0.1.6.0
visibility:           public
id:                   wide-word-0.1.6.0-OR0gnrrBFA8ayx7QfAp8V
key:                  wide-word-0.1.6.0-OR0gnrrBFA8ayx7QfAp8V
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  636a55e77d083b7eb388a86ea8712f0a
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wide-word-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wide-word-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.6.0-OR0gnrrBFA8ayx7QfAp8V
depends:
    base-4.16.4.0 binary-0.8.9.0 deepseq-1.4.6.1 ghc-prim-0.8.0
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wide-word-0.1.6.0-36-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wide-word
version:              0.1.6.0
visibility:           public
id:                   wide-word-0.1.6.0-BshjjA2TFaS17wD9UHnoX1
key:                  wide-word-0.1.6.0-BshjjA2TFaS17wD9UHnoX1
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  770a5a53574db2dd3c0f354ba6b58341
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wide-word-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wide-word-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.6.0-BshjjA2TFaS17wD9UHnoX1
depends:
    base-4.16.4.0 binary-0.8.9.0 deepseq-1.4.6.1 ghc-prim-0.8.0
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
